function M=logical2int(varargin)
%Store a maximum of 8 logicals in uint8 variable
% 
% CALL
%     M=int2logical(L)
%     M=int2logical(L1,L2)
%     M=int2logical(L1,L2,...L8)
% 
% INPUT
%     ONE INPUT ARGUMENT:
%         L: logical array 
%            height= number of bits
%            other dimensions: size of output matrix 
%     > ONE INPUT ARGUMENT:
%         L1,L2: logical arrays of equal size
%            output dimension is equal to input dimension
%     
% OUTPUT
%     M(1,I1)
%     M(I1,I2,....)
% 
% NOTE
%                     logical2int             int2logical
%     1x1     logical     ==>     1x1   uint8     ==>   8x1 logical  
%     MxN     logical     ==>     1xN   uint8     ==>   8xN logical  
%     Mx1xN   logical     ==>     1xN   uint8     ==>   8xN logical  !!
%     MxNxPxQ logical     ==>     NxPxQ uint8     ==>   8xNxPxQ logical  
% 
% EXAMPLE
%     L1=rand(3)>.5
%     L2=rand(3)>.5
%     L=false(2,3,3);
%     L(1,:,:)=L1;
%     L(2,:,:)=L2;
%     M1=logical2int(L1,L2) %store
%     M2=logical2int(L) %store
%     LL=int2logical(M); %retrieve
%     is_eq(L,LL)
% 
% SEE ALSO
%     int2logical, bitset

if nargin==0
    L=logical([0 0 1 1 ; 0 1 0 1]);
    M=logical2int(L);
    return
end

%All input arguments must be logical
for k=1:length(varargin)
    if ~strcmp(class(varargin{k}),'logical')
        error('function only applies to logicals.');
    end
end

if length(varargin)==1
    L=varargin{1};
    
    %empty returns empty
    if isempty(L)
        M=zeros([0 0],'uint8');
        return
    end

    %last dimension contains status bits
    NUMBITS=size(L,1);
    if NUMBITS>8
        error('a maximum of 8 bits can be stored.');
    end
    sz=size(L);
    newsize=sz(2:end);
    if length(newsize)==1
        newsize=[1,newsize];
    end

    L=uint8(reshape(L,NUMBITS,prod(sz(2:end))));
    M=L(1,:);
    for k=2:NUMBITS
        M=M+bitshift(L(k,:),k-1);
    end
    M=reshape(M,newsize);
else
    %multiple arguments
    %alternative methode
    sz=size(varargin{1});
    NUMBITS=length(varargin);
    %check size
    if NUMBITS>8
        error('a maximum of 8 bits can be stored.');
    end
    M=uint8(varargin{1});
    for k=2:length(varargin)        
        M=M+bitshift(uint8(varargin{k}),k-1);
    end
end

